import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

///
/// Block Container
///
/// +-----+
/// |  1  |
/// +-----+
///
/// ### Example:
/// ```dart
/// Block(
///   width: 80.0,
///   height: 80.0,
///   title: "1",
///   color: Colors.blueAccent
/// )
/// ```
///
class Block extends StatelessWidget {
  Block(
      {Key key,
      this.width = 80.0,
      this.height = 80.0,
      this.title = "",
      this.color = Colors.blueAccent})
      : super(key: key);

  ///
  /// 宽
  ///
  final double width;

  ///
  /// 高
  ///
  final double height;

  ///
  /// 标题
  ///
  final String title;

  ///
  /// 背景色
  ///
  final Color color;

  @override
  Widget build(BuildContext context) {
    return Container(
      color: color,
      width: width,
      height: height,
      child: Center(
          child: Text(
        title,
        style: TextStyle(color: Colors.black, fontStyle: FontStyle.normal),
      )),
    );
  }
}

// 渐变色色值，设置在BoxDecoration中gradient。
// Color(0xffffcb52),
// Color(0xffff7b02)
// Color(0xff2afeb7),
// Color(0xff08c792),
// Color(0xff5581f1),
// Color(0xff1153fc),
// Color(0xffffe324),
// Color(0xffffb533),
// Color(0xff1de5e2),
// Color(0xffb588f7),
// Color(0xff00f7a7),
// Color(0xff04f5ed),
// Color(0xfffacd68),
// Color(0xfffc76b3),
// Color(0xff31fffa),
// Color(0xff1dbcbb),
